from setuptools import setup

setup(name='anshils',
      version='0.1.7',
      description='pip install anshils',
      packages=['anshils'],
      author_email='i89041056398@gmail.com',
      zip_safe=False)
